From mboxrd@z Thu Jan 1 00:00:00 1970 Return-Path: Received: (majordomo@vger.kernel.org) by vger.kernel.org via listexpand id S1422644Ab3LTOIY (ORCPT ); Fri, 20 Dec 2013 09:08:24 -0500 Received: from ringil.hengli.com.au ([178.18.16.133]:54734 "EHLO ringil.hengli.com.au" rhost-flags-OK-OK-OK-OK) by vger.kernel.org with ESMTP id S932535Ab3LTOIW (ORCPT ); Fri, 20 Dec 2013 09:08:22 -0500 Date: Fri, 20 Dec 2013 22:08:02 +0800 From: Herbert Xu To: Tim Chen Cc: "H. Peter Anvin" , "David S.Miller" , Erdinc Ozturk , Vinodh Gopal , James Guilford , Wajdi Feghali , Jussi Kivilinna , Huang Ying , Alessandro Salvatori , linux-kernel , linux-crypto@vger.kernel.org Subject: Re: [PATCH 1/2] crypto: AVX and AVX2 version of AESNI-GCM encode and decode Message-ID: <20131220140802.GC356@gondor.apana.org.au> References: <1386800921.2624.9.camel@schen9-DESK> MIME-Version: 1.0 Content-Type: text/plain; charset=us-ascii Content-Disposition: inline In-Reply-To: <1386800921.2624.9.camel@schen9-DESK> User-Agent: Mutt/1.5.21 (2010-09-15) Sender: linux-kernel-owner@vger.kernel.org List-ID: X-Mailing-List: linux-kernel@vger.kernel.org On Wed, Dec 11, 2013 at 02:28:41PM -0800, Tim Chen wrote: > We have added AVX and AVX2 routines that optimize AESNI-GCM encode/decode. > These routines are optimized for encrypt and decrypt of large buffers. > In tests we have seen up to 6% speedup for 1K, 11% speedup for 2K and > 18% speedup for 8K buffer over the existing SSE version. These routines > should provide even better speedup for future Intel x86_64 cpus. > > Signed-off-by: Tim Chen Both patches applied. Thanks! -- Email: Herbert Xu Home Page: http://gondor.apana.org.au/~herbert/ PGP Key: http://gondor.apana.org.au/~herbert/pubkey.txt